package test05.mapper;

import org.apache.ibatis.annotations.Mapper;
import test05.pojo.Course;

import java.util.List;

@Mapper
public interface CourseMapper {
    /**
     * 查询课程
     * @param course 作为查询条件，该对象中的默认值表示不对该项筛选。
     * @return 查询结果集
     */
    List<Course> selectCourse(Course course, int offset, int pageSize);

    /**
     * 插入课程
     * @param course 要插入的课程
     * @return 影响的行数，大于0时表示插入成功
     */
    int insertCourse(Course course);

    /**
     * 更新课程
     * @param course 更新的课程，id作为更新条件，所有其他字段都将会被更新
     * @return 影响的行数，行数大于0时表示根性成功
     */
    int updateCourse(Course course);

    /**
     * 删除课程
     * @param course 删除的课程，id作为删除条件
     * @return 影响的行数，行数大于0时表示删除成功
     */
    int deleteCourse(Course course);

    int selectCourseCount(Course course);
}
